@@ -105,7 +105,7 @@ class ObjectProxy(with_metaclass(_ObjectProxyMetaType)):
 
     @property
     def __annotations__(self):
-        return self.__wrapped__.__anotations__
+        return self.__wrapped__.__annotations__
 
     @__annotations__.setter
     def __annotations__(self, value):
@@ -122,7 +122,7 @@ class ObjectProxy(with_metaclass(_ObjectProxyMetaType)):
             return bytes(self.__wrapped__)
 
     def __repr__(self):
-        return '<%s at 0x%x for %s at 0x%x>' % (
+        return '<{} at 0x{:x} for {} at 0x{:x}>'.format(
                 type(self).__name__, id(self),
                 type(self.__wrapped__).__name__,
                 id(self.__wrapped__))
@@ -134,6 +134,10 @@ class ObjectProxy(with_metaclass(_ObjectProxyMetaType)):
         def __round__(self):
             return round(self.__wrapped__)
 
+    if sys.hexversion >= 0x03070000:
+        def __mro_entries__(self, bases):
+            return (self.__wrapped__,)
+
     def __lt__(self, other):
         return self.__wrapped__ < other
 
@@ -369,6 +373,9 @@ class ObjectProxy(with_metaclass(_ObjectProxyMetaType)):
     def __float__(self):
         return float(self.__wrapped__)
 
+    def __complex__(self):
+        return complex(self.__wrapped__)
+
     def __oct__(self):
         return oct(self.__wrapped__)
 
@@ -411,11 +418,49 @@ class ObjectProxy(with_metaclass(_ObjectProxyMetaType)):
     def __iter__(self):
         return iter(self.__wrapped__)
 
+    def __copy__(self):
+        raise NotImplementedError('object proxy must define __copy__()')
+
+    def __deepcopy__(self, memo):
+        raise NotImplementedError('object proxy must define __deepcopy__()')
+
+    def __reduce__(self):
+        raise NotImplementedError(
+                'object proxy must define __reduce_ex__()')
+
+    def __reduce_ex__(self, protocol):
+        raise NotImplementedError(
+                'object proxy must define __reduce_ex__()')
+
 class CallableObjectProxy(ObjectProxy):
 
     def __call__(self, *args, **kwargs):
         return self.__wrapped__(*args, **kwargs)
 
+class PartialCallableObjectProxy(ObjectProxy):
+
+    def __init__(self, *args, **kwargs):
+        if len(args) < 1:
+            raise TypeError('partial type takes at least one argument')
+
+        wrapped, args = args[0], args[1:]
+
+        if not callable(wrapped):
+            raise TypeError('the first argument must be callable')
+
+        super(PartialCallableObjectProxy, self).__init__(wrapped)
+
+        self._self_args = args
+        self._self_kwargs = kwargs
+
+    def __call__(self, *args, **kwargs):
+        _args = self._self_args + args
+
+        _kwargs = dict(self._self_kwargs)
+        _kwargs.update(kwargs)
+
+        return self.__wrapped__(*_args, **_kwargs)
+
 class _FunctionWrapperBase(ObjectProxy):
 
     __slots__ = ('_self_instance', '_self_wrapper', '_self_enabled',
@@ -555,7 +600,7 @@ class BoundFunctionWrapper(_FunctionWrapperBase):
                     raise TypeError('missing 1 required positional argument')
 
                 instance, args = args[0], args[1:]
-                wrapped = functools.partial(self.__wrapped__, instance)
+                wrapped = PartialCallableObjectProxy(self.__wrapped__, instance)
                 return self._self_wrapper(wrapped, instance, args, kwargs)
 
             return self._self_wrapper(self.__wrapped__, self._self_instance,
@@ -678,7 +723,8 @@ class FunctionWrapper(_FunctionWrapperBase):
 try:
     if not os.environ.get('WRAPT_DISABLE_EXTENSIONS'):
         from ._wrappers import (ObjectProxy, CallableObjectProxy,
-            FunctionWrapper, BoundFunctionWrapper, _FunctionWrapperBase)
+            PartialCallableObjectProxy, FunctionWrapper,
+            BoundFunctionWrapper, _FunctionWrapperBase)
 except ImportError:
     pass
 
